@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2012-2015 Bastian Kleineidam
+# Copyright (C) 2012-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,26 +17,23 @@
 from .. import fileutil, util
 import lzma
 
-READ_SIZE_BYTES = 1024*1024
+READ_SIZE_BYTES = 1024 * 1024
 
 # Adapters for different lzma bindings.
 if hasattr(lzma, 'FORMAT_ALONE'):
+
     def _get_lzma_options(format):
         return {
             'format': {
                 'alone': lzma.FORMAT_ALONE,
                 'xz': lzma.FORMAT_XZ,
-                }[format]
-            }
+            }[format]
+        }
 else:
     # might not be available e.g. in Debian's python-lzma 0.5.3
     # which is pyliblzma.
     def _get_lzma_options(format):
-        return {
-            'options': {
-                'format': format
-            }
-        }
+        return {'options': {'format': format}}
 
 
 def _extract(archive, compression, cmd, format, verbosity, outdir):
@@ -55,10 +51,12 @@ def _extract(archive, compression, cmd, format, verbosity, outdir):
         raise util.PatoolError(msg) from err
     return None
 
+
 def extract_lzma(archive, compression, cmd, verbosity, interactive, outdir):
     """Extract an LZMA archive with the lzma Python module."""
     return _extract(archive, compression, cmd, 'alone', verbosity, outdir)
 
+
 def extract_xz(archive, compression, cmd, verbosity, interactive, outdir):
     """Extract an XZ archive with the lzma Python module."""
     return _extract(archive, compression, cmd, 'xz', verbosity, outdir)
@@ -80,10 +78,12 @@ def _create(archive, compression, cmd, format, verbosity, filenames):
         raise util.PatoolError(f"error creating {archive}") from err
     return None
 
+
 def create_lzma(archive, compression, cmd, verbosity, interactive, filenames):
     """Create an LZMA archive with the lzma Python module."""
     return _create(archive, compression, cmd, 'alone', verbosity, filenames)
 
+
 def create_xz(archive, compression, cmd, verbosity, interactive, filenames):
     """Create an XZ archive with the lzma Python module."""
     return _create(archive, compression, cmd, 'xz', verbosity, filenames)
