@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,15 +13,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the uncompress.real program."""
+
 from .. import util, fileutil
 
 
-def extract_compress (archive, compression, cmd, verbosity, interactive, outdir):
+def extract_compress(archive, compression, cmd, verbosity, interactive, outdir):
     """Extract a compressed archive."""
     cmdlist = [util.shell_quote(cmd)]
     if verbosity > 1:
         cmdlist.append('-v')
     outfile = fileutil.get_single_outfile(outdir, archive)
-    cmdlist.extend(['-c', util.shell_quote(archive), '>',
-                    util.shell_quote(outfile)])
+    cmdlist.extend(['-c', util.shell_quote(archive), '>', util.shell_quote(outfile)])
     return (cmdlist, {'shell': True})
