@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,17 +14,22 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the unzip program."""
 
+
 def _maybe_add_password(cmdlist, password):
     if password:
         cmdlist.extend(['-P', password])
 
-def extract_zip(archive, compression, cmd, verbosity, interactive, outdir, password=None):
+
+def extract_zip(
+    archive, compression, cmd, verbosity, interactive, outdir, password=None
+):
     """Extract a ZIP archive."""
     cmdlist = [cmd]
     _maybe_add_password(cmdlist, password)
     cmdlist.extend(['--', archive, '-d', outdir])
     return cmdlist
 
+
 def list_zip(archive, compression, cmd, verbosity, interactive, password=None):
     """List a ZIP archive."""
     cmdlist = [cmd, '-l']
@@ -35,6 +39,7 @@ def list_zip(archive, compression, cmd, verbosity, interactive, password=None):
     cmdlist.extend(['--', archive])
     return cmdlist
 
+
 def test_zip(archive, compression, cmd, verbosity, interactive, password=None):
     """Test a ZIP archive."""
     cmdlist = [cmd, '-t']
