@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,13 +12,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the compress program"""
+
 from . import ArchiveTest, Content
 from .. import needs_program
 
-class TestCompress (ArchiveTest):
+
+class TestCompress(ArchiveTest):
+    """Test class for the compress program"""
 
     program = 'compress'
 
     @needs_program(program)
-    def test_compress (self):
+    def test_compress(self):
+        """Create a COMPRESS archive."""
         self.archive_create('t.txt.Z', check=Content.Singlefile)
