@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,21 +12,26 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the shorten program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestShorten (ArchiveTest):
+
+class TestShorten(ArchiveTest):
+    """Test class for the shorten program"""
 
     program = 'shorten'
 
     @needs_program(program)
     def test_shorten(self):
+        """Extract and create SHORTEN archives."""
         self.archive_extract('t.shn', check=None)
         self.archive_create('t.shn', srcfiles=("t.wav",))
 
     # file(1) does not recognize .shn files
-    #@needs_program('file')
-    #@needs_program(program)
-    #def test_shorten_file(self):
+    # @needs_program('file')
+    # @needs_program(program)
+    # def test_shorten_file(self):
+    #    """Extract a renamed SHORTEN archive."""
     #    self.archive_extract('t.shn.foo', check=None)
-
