@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,20 +12,26 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the zpaq program"""
+
 from . import ArchiveTest, Content
 from .. import needs_program
 
+
 class TestZpaq(ArchiveTest):
+    """Test class for the zpaq program"""
 
     program = 'zpaq'
 
     @needs_program(program)
     def test_zpaq(self):
+        """Run archive commands with ZPAQ archive."""
         self.archive_commands('t.zpaq', check=Content.Multifile)
 
     @needs_program('file')
     @needs_program(program)
     def test_zpaq_file(self):
+        """Run archive commands with renamed ZPAQ archive."""
         self.archive_extract('t.zpaq.foo', check=Content.Multifile)
         self.archive_test('t.zpaq.foo')
         self.archive_list('t.zpaq.foo')
